@@ -90,6 +90,15 @@ ppb_host_resolver_resolve(PP_Resource host_resolver, const char *host, uint16_t
     return PP_OK_COMPLETIONPENDING;
 }
 
+int32_t
+ppb_host_resolver_resolve_1_0(PP_Resource host_resolver, const char *host, uint16_t port,
+                              const struct PP_HostResolver_Hint *hint,
+                              struct PP_CompletionCallback callback)
+{
+    // TODO: use 'hint' somehow?
+    return ppb_host_resolver_resolve(host_resolver, host, port, NULL, callback);
+}
+
 struct PP_Var
 ppb_host_resolver_get_canonical_name(PP_Resource host_resolver)
 {
@@ -120,6 +129,12 @@ ppb_host_resolver_get_size(PP_Resource host_resolver)
     return count;
 }
 
+uint32_t
+ppb_host_resolver_get_net_address_count(PP_Resource host_resolver)
+{
+    return ppb_host_resolver_get_size(host_resolver);
+}
+
 PP_Bool
 ppb_host_resolver_get_net_address(PP_Resource host_resolver, uint32_t index,
                                   struct PP_NetAddress_Private *addr)
@@ -141,6 +156,35 @@ ppb_host_resolver_get_net_address(PP_Resource host_resolver, uint32_t index,
     return PP_TRUE;
 }
 
+PP_Resource
+ppb_host_resolver_get_net_address_1_0(PP_Resource host_resolver, uint32_t index)
+{
+    PP_Resource net_address = 0;
+    struct pp_host_resolver_s *hr = pp_resource_acquire(host_resolver, PP_RESOURCE_HOST_RESOLVER);
+    if (!hr) {
+        trace_error("%s, bad resource\n", __func__);
+        goto err_1;
+    }
+
+    if (index >= hr->addr_count)
+        goto err_2;
+
+    net_address = pp_resource_allocate(PP_RESOURCE_NET_ADDRESS, hr->instance);
+    struct pp_net_address_s *na = pp_resource_acquire(net_address, PP_RESOURCE_NET_ADDRESS);
+    if (!na) {
+        trace_error("%s, resource allocation failed\n", __func__);
+        goto err_2;
+    }
+
+    memcpy(&na->addr, &hr->addrs[index], sizeof(struct PP_NetAddress_Private));
+    pp_resource_release(net_address);
+
+err_2:
+    pp_resource_release(host_resolver);
+err_1:
+    return net_address;
+}
+
 
 // trace wrappers
 TRACE_WRAPPER
@@ -171,6 +215,18 @@ trace_ppb_host_resolver_resolve(PP_Resource host_resolver, const char *host, uin
     return ppb_host_resolver_resolve(host_resolver, host, port, hint, callback);
 }
 
+TRACE_WRAPPER
+int32_t
+trace_ppb_host_resolver_resolve_1_0(PP_Resource host_resolver, const char *host, uint16_t port,
+                                    const struct PP_HostResolver_Hint *hint,
+                                    struct PP_CompletionCallback callback)
+{
+    trace_info("[PPB] {full} %s host_resolver=%d, host=%s, port=%u, hint=%p, callback={.func=%p, "
+               ".user_data=%p, .flags=%u}\n", __func__+6, host_resolver, host, (unsigned int)port,
+               hint, callback.func, callback.user_data, callback.flags);
+    return ppb_host_resolver_resolve_1_0(host_resolver, host, port, hint, callback);
+}
+
 TRACE_WRAPPER
 struct PP_Var
 trace_ppb_host_resolver_get_canonical_name(PP_Resource host_resolver)
@@ -187,6 +243,14 @@ trace_ppb_host_resolver_get_size(PP_Resource host_resolver)
     return ppb_host_resolver_get_size(host_resolver);
 }
 
+TRACE_WRAPPER
+uint32_t
+trace_ppb_host_resolver_get_net_address_count(PP_Resource host_resolver)
+{
+    trace_info("[PPB] {full} %s host_resolver=%d\n", __func__+6, host_resolver);
+    return ppb_host_resolver_get_net_address_count(host_resolver);
+}
+
 TRACE_WRAPPER
 PP_Bool
 trace_ppb_host_resolver_get_net_address(PP_Resource host_resolver, uint32_t index,
@@ -196,6 +260,14 @@ trace_ppb_host_resolver_get_net_address(PP_Resource host_resolver, uint32_t inde
     return ppb_host_resolver_get_net_address(host_resolver, index, addr);
 }
 
+TRACE_WRAPPER
+PP_Resource
+trace_ppb_host_resolver_get_net_address_1_0(PP_Resource host_resolver, uint32_t index)
+{
+    trace_info("[PPB] {full} %s host_resolver=%d, index=%u\n", __func__+6, host_resolver, index);
+    return ppb_host_resolver_get_net_address_1_0(host_resolver, index);
+}
+
 
 const struct PPB_HostResolver_Private_0_1 ppb_host_resolver_private_interface_0_1 = {
     .Create =           TWRAPF(ppb_host_resolver_create),
@@ -206,6 +278,15 @@ const struct PPB_HostResolver_Private_0_1 ppb_host_resolver_private_interface_0_
     .GetNetAddress =    TWRAPF(ppb_host_resolver_get_net_address),
 };
 
+const struct PPB_HostResolver_1_0 ppb_host_resolver_interface_1_0 = {
+    .Create =               TWRAPF(ppb_host_resolver_create),
+    .IsHostResolver =       TWRAPF(ppb_host_resolver_is_host_resolver),
+    .Resolve =              TWRAPF(ppb_host_resolver_resolve_1_0),
+    .GetCanonicalName =     TWRAPZ(ppb_host_resolver_get_canonical_name),
+    .GetNetAddressCount =   TWRAPF(ppb_host_resolver_get_net_address_count),
+    .GetNetAddress =        TWRAPF(ppb_host_resolver_get_net_address_1_0),
+};
+
 static
 void
 __attribute__((constructor))
@@ -213,5 +294,6 @@ constructor_ppb_host_resolver(void)
 {
     register_interface(PPB_HOSTRESOLVER_PRIVATE_INTERFACE_0_1,
                        &ppb_host_resolver_private_interface_0_1);
+    register_interface(PPB_HOSTRESOLVER_INTERFACE_1_0, &ppb_host_resolver_interface_1_0);
     register_resource(PP_RESOURCE_HOST_RESOLVER, ppb_host_resolver_destroy);
 }
