@@ -1164,61 +1164,6 @@ reverse_x509_certificate_field(PP_X509Certificate_Private_Field field)
     }
 }
 
-const char *
-reverse_resource_image(PP_ResourceImage resource_image)
-{
-    switch (resource_image) {
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_FTP);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_FTP_HOVER);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_FTP_PRESSED);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_FTW);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_FTW_HOVER);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_FTW_PRESSED);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_ZOOMIN);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_ZOOMIN_HOVER);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_ZOOMIN_PRESSED);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_ZOOMOUT);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_ZOOMOUT_HOVER);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_ZOOMOUT_PRESSED);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_THUMBNAIL_0);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_THUMBNAIL_1);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_THUMBNAIL_2);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_THUMBNAIL_3);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_THUMBNAIL_4);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_THUMBNAIL_5);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_THUMBNAIL_6);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_THUMBNAIL_7);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_THUMBNAIL_8);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_THUMBNAIL_9);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_THUMBNAIL_NUM_BACKGROUND);
-    CASE(PP_RESOURCEIMAGE_PDF_PROGRESS_BAR_0);
-    CASE(PP_RESOURCEIMAGE_PDF_PROGRESS_BAR_1);
-    CASE(PP_RESOURCEIMAGE_PDF_PROGRESS_BAR_2);
-    CASE(PP_RESOURCEIMAGE_PDF_PROGRESS_BAR_3);
-    CASE(PP_RESOURCEIMAGE_PDF_PROGRESS_BAR_4);
-    CASE(PP_RESOURCEIMAGE_PDF_PROGRESS_BAR_5);
-    CASE(PP_RESOURCEIMAGE_PDF_PROGRESS_BAR_6);
-    CASE(PP_RESOURCEIMAGE_PDF_PROGRESS_BAR_7);
-    CASE(PP_RESOURCEIMAGE_PDF_PROGRESS_BAR_8);
-    CASE(PP_RESOURCEIMAGE_PDF_PROGRESS_BAR_BACKGROUND);
-    CASE(PP_RESOURCEIMAGE_PDF_PAGE_DROPSHADOW);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_SAVE);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_SAVE_HOVER);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_SAVE_PRESSED);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_PRINT);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_PRINT_HOVER);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_PRINT_PRESSED);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_ZOOMIN_END);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_ZOOMIN_END_HOVER);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_ZOOMIN_END_PRESSED);
-    CASE(PP_RESOURCEIMAGE_PDF_PAN_SCROLL_ICON);
-    CASE(PP_RESOURCEIMAGE_PDF_PAGE_INDICATOR_BACKGROUND);
-    CASE(PP_RESOURCEIMAGE_PDF_BUTTON_PRINT_DISABLED);
-    default:
-        return "UNKNOWNRESOURCEIMAGE";
-    }
-}
-
 const char *
 reverse_pdf_feature(PP_PDFFeature feature)
 {
@@ -1230,19 +1175,6 @@ reverse_pdf_feature(PP_PDFFeature feature)
     }
 }
 
-const char *
-reverse_resource_string(PP_ResourceString resource_string)
-{
-    switch (resource_string) {
-    CASE(PP_RESOURCESTRING_PDFGETPASSWORD);
-    CASE(PP_RESOURCESTRING_PDFLOADING);
-    CASE(PP_RESOURCESTRING_PDFLOAD_FAILED);
-    CASE(PP_RESOURCESTRING_PDFPROGRESSLOADING);
-    default:
-        return "UNKNOWNRESOURCESTRING";
-    }
-}
-
 const char *
 reverse_private_font_charset(PP_PrivateFontCharset charset)
 {
@@ -1271,19 +1203,6 @@ reverse_private_font_charset(PP_PrivateFontCharset charset)
     }
 }
 
-const char *
-reverse_scrollby(PP_ScrollBy_Dev unit)
-{
-    switch (unit) {
-    CASE(PP_SCROLLBY_PIXEL);
-    CASE(PP_SCROLLBY_LINE);
-    CASE(PP_SCROLLBY_PAGE);
-    CASE(PP_SCROLLBY_DOCUMENT);
-    default:
-        return "UNKNONWSCROLLBY";
-    }
-}
-
 const char *
 reverse_graphics3d_attribute(int32_t attr)
 {
