@@ -28,6 +28,7 @@
 #include <ppapi/c/pp_graphics_3d.h>
 #include <glib.h>
 #include <inttypes.h>
+#include <arpa/inet.h>
 
 
 static
@@ -341,7 +342,7 @@ trace_netaddress_ipv4_as_string(const struct PP_NetAddress_IPv4 *addr)
         return g_strdup_printf("(nil)");
 
     return g_strdup_printf("%u.%u.%u.%u:%u", addr->addr[0], addr->addr[1], addr->addr[2],
-                           addr->addr[3], addr->port);
+                           addr->addr[3], ntohs(addr->port));
 }
 
 char *
@@ -355,5 +356,5 @@ trace_netaddress_ipv6_as_string(const struct PP_NetAddress_IPv6 *addr)
                            addr->addr[3], addr->addr[4], addr->addr[5], addr->addr[6],
                            addr->addr[7], addr->addr[8], addr->addr[9], addr->addr[10],
                            addr->addr[11], addr->addr[12], addr->addr[13], addr->addr[14],
-                           addr->addr[15], addr->port);
+                           addr->addr[15], ntohs(addr->port));
 }
